@@ -1,4 +1,4 @@
 """Low level connector to the API."""
 # pylint: disable=cyclic-import
-from .error import ApiError
+from .error import ApiError, WrongResponseError
 from .connector import Connector
